# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.

from typing import Optional, Literal
from microsoft_agents.activity.entity import Entity
from .notification_types import NotificationTypes


class EmailReference(Entity):
    type: Literal["emailNotification"] = NotificationTypes.EMAIL_NOTIFICATION
    id: Optional[str] = None
    conversation_id: Optional[str] = None
    html_body: Optional[str] = None



# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.

from .agent_notification_activity import AgentNotificationActivity
from .email_reference import EmailReference
from .wpx_comment import WpxComment
from .email_response import EmailResponse
from .notification_types import NotificationTypes
from .agent_subchannel import AgentSubChannel
from .agent_lifecycle_event import AgentLifecycleEvent

__all__ = [
    "AgentNotificationActivity",
    "EmailReference",
    "WpxComment",
    "EmailResponse",
    "NotificationTypes",
    "AgentSubChannel",
    "AgentLifecycleEvent",
]
